Python: module error_pages

error_pages (version 0.0.3) | index error_pages.py

`This tools run scripts and display the result in a Web Interface.
This file implement error, report and request pages by default.`

Modules
`` |  |
csv | json | ntpath | secrets

Classes
`` |  | builtins.object Report Request
class Report(builtins.object)
`` | `This class implements pages for the report feature by default.`
| Methods defined here: new(environ: os._Environ, user: ~User, configuration: ~ServerConfiguration, code: str, arguments: List[str], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], str] `This function returns the report page by default.` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class Request(builtins.object)
`` | `This class implements pages for the report feature by default.`
| Methods defined here: save(username: str, code: str, url: str, user_agent: str, subject: str, name: str, reason: str) -> None `This function save the report/request to a CSV file.` send(environ: os._Environ, user: ~User, configuration: ~ServerConfiguration, code: str, arguments: List[str], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], str] `This function save and send request or report.` send_mail(configuration: ~ServerConfiguration, notification: str) -> None `This function send a notification mail.` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`

Functions
`` |  | page_401(error: str) -> Tuple[str, Dict[str, str], List[bytes]] `This function uses send_error_page to return the page 401 by default.` page_403(error: str) -> Tuple[str, Dict[str, str], List[bytes]] `This function uses send_error_page to return the page 403 by default.` page_404(error: str) -> Tuple[str, Dict[str, str], List[bytes]] `This function uses send_error_page to return the page 404 by default.` page_500(error: str) -> Tuple[str, Dict[str, str], List[bytes]] `This function uses send_error_page to return the page 500 by default.`

Data
`` |  | __all__ = ['page_500', 'page_401', 'page_403', 'page_404', 'Request', 'Report'] __author_email__ = 'mauricelambert434@gmail.com' __copyright__ = '\nWebScripts Copyright (C) 2021 Maurice Lambert...ome to redistribute it\nunder certain conditions.\n' __description__ = '\nThis tools run scripts and display the result i...ement errors and report/request pages by default.' __license__ = 'GPL-3.0 License' __maintainer__ = 'Maurice Lambert' __maintainer_email__ = 'mauricelambert434@gmail.com' __url__ = 'https://github.com/mauricelambert/WebScripts'

Author
`` |  | Maurice Lambert